exceptiontools.TupletError
==========================

.. inheritance-diagram:: abjad.tools.exceptiontools.TupletError.TupletError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TupletError.TupletError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TupletError.TupletError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
